"use strict";

var _slice = Array.prototype.slice;
var _toArray = function (arr) {
  return Array.isArray(arr) ? arr : Array.from(arr);
};

var _classProps = function (child, staticProps, instanceProps) {
  if (staticProps) Object.defineProperties(child, staticProps);
  if (instanceProps) Object.defineProperties(child.prototype, instanceProps);
};

var NanoEventEmitter = (function () {
  var NanoEventEmitter = function NanoEventEmitter() {
    this.observers = {};
  };

  _classProps(NanoEventEmitter, null, {
    on: {
      writable: true,
      value: function (events, listener) {
        var _this = this;
        events.split(" ").forEach(function (event) {
          _this.observers[event] = _this.observers[event] || [];
          _this.observers[event].push(listener);
        });
      }
    },
    off: {
      writable: true,
      value: function (event, listener) {
        var _this2 = this;
        if (!this.observers[event]) {
          return;
        }

        this.observers[event].forEach(function () {
          if (!listener) {
            delete _this2.observers[event];
          } else {
            var index = _this2.observers[event].indexOf(listener);
            if (index > -1) {
              _this2.observers[event].splice(index, 1);
            }
          }
        });
      }
    },
    emit: {
      writable: true,
      value: function (event) {
        var args = _slice.call(arguments, 1);

        if (!this.observers[event]) {
          return;
        }

        this.observers[event].forEach(function (observer) {
          observer.apply(null, _toArray(args));
        });
      }
    }
  });

  return NanoEventEmitter;
})();

module.exports = NanoEventEmitter;